@@ -4,6 +4,7 @@ from ..utils.utils import logResult
 from ..core.command import Command
 import cssutils
 
+
 class FigmaGenerateTextCommand(Command):
     def __init__(self, css_text):
         super(FigmaGenerateTextCommand, self).__init__()
@@ -16,21 +17,22 @@ class FigmaGenerateTextCommand(Command):
         for rule in sheet:
             styles = rule.style.cssText
             for property in rule.style:
-                name = property.name    
+                name = property.name
                 value = property.value
-                dct[name] = value;
+                dct[name] = value
                 # print("%s - %s" % (name, value))
                 if name in CSS_METHOD:
                     try:
-                        result += '\n    .{}'.format(CSS_METHOD[name] % value.lower()) 
+                        result += '\n    .{}'.format(
+                            CSS_METHOD[name] % value.lower())
                     except TypeError as e:
                         value = value.lower().replace('px', '').replace('em', '')
                         if 'number is required' in str(e):
-                            #int
-                            result += '\n    .{}'.format(CSS_METHOD[name] % int(value)) 
+                            # int
+                            result += '\n    .{}'.format(
+                                CSS_METHOD[name] % int(value))
                         elif 'real number' in str(e):
-                            #float
-                            result += '\n    .{}'.format(CSS_METHOD[name] % float(value))
+                            # float
+                            result += '\n    .{}'.format(
+                                CSS_METHOD[name] % float(value))
         logResult(result)
-
-
