@@ -8,6 +8,7 @@ from ..utils.file_helpers import *
 from ..utils.utils import *
 from flutter_gen.utils.dart_helpers import format_dart_file_code
 from flutter_gen.utils.print import *
+from sys import platform
 
 
 class RouterInfo:
@@ -43,15 +44,19 @@ class GenerateRouterCommand(Command):
                     route_name = re.sub(
                         '(?<!^)(?=[A-Z])', '_', class_name).upper()
                     args = class_name + "Args"
-                    is_include_args = "%s {}" % (args) not in content
+                    is_include_args = args in content
                     import_files.append(file)
                     item = RouterInfo(class_name, is_include_args, route_name)
                     items.append(item)
 
         package_name = get_current_dart_package_name()
         import_files = list(dict.fromkeys(import_files))
-        import_files = list(map(lambda x: x.replace(
-            "lib/", 'package:%s/' % package_name).replace('\\', '/'), import_files))
+        if platform == "darwin":
+            import_files = list(map(lambda x: x.replace(
+                "lib/", 'package:%s/' % package_name).replace('\\', '/'), import_files))
+        else:
+            import_files = list(map(lambda x: x.replace(
+                "lib\\", 'package:%s/' % package_name).replace('\\', '/'), import_files))
 
         env = Environment(
             loader=PackageLoader('flutter_gen_templates', 'gen'),
